@@ -1,4 +1,3 @@
-#' Influential clade detection - Phylogenetic Logistic Regression
 #'
 #' Estimate the impact on model estimates of phylogenetic logistic regression after 
 #' removing clades from the analysis. 
@@ -9,31 +8,45 @@
 #' @param phy A phylogeny (class 'phylo') matching \code{data}.
 #' @param btol Bound on searching space. For details see \code{phyloglm}
 #' @param track Print a report tracking function progress (default = TRUE)
-#' @param clade.col The name of a column in the provided data frame with clades 
-#' specification (a character vector with clade names).
-#' @param n.species Minimum number of species in the clade in order to include
-#' this clade in the leave-one-out deletion analyis. Default is \code{5}.
-#' @param times Number of simulations for the randomization test.
+#' @param clade.col The column in the provided data frame which specifies the
+#' clades (a character vector with clade names).
+#' @param n.species Minimum number of species in a clade for the clade to be
+#' included in the leave-one-out deletion analysis. Default is \code{5}.
+#' @param n.sim Number of simulations for the randomization test.
 #' @param ... Further arguments to be passed to \code{phyloglm}
 #' 
 #' @details
-#' Currently only logistic regression using the "logistic_MPLE"-method from
+#' This function sequentially removes one clade at a time, fits a phylogenetic
+#' logistic regression model using \code{\link[phylolm]{phyloglm}} and stores the
+#' results. The impact of of a specific clade on model estimates is calculated by a
+#' comparison between the full model (with all species) and the model without 
+#' the species belonging to a clade.
+#' 
+#' To account for the influence of the number of species on each 
+#' clade (clade sample size), this function also estimates a null distribution
+#' expected for the number of species in a given clade. This is done by fitting
+#'  models without the same number of species as in the given clade. 
+#'  The number of simulations to be performed is set by 'n.sim'. To test if the 
+#'  clade influence differs from the null expectation for a clade of that size, 
+#'  a randomization test can be performed using 'summary(x)'. 
+#'
+#' Currently, only logistic regression using the "logistic_MPLE"-method from
 #' \code{phyloglm} is implemented.
 #'
 #' \code{clade_phyglm} detects influential clades based on
-#' difference in intercept and/or slope when removing a given clade compared
+#' difference in intercept and/or estimate when removing a given clade compared
 #' to the full model including all species.
 #' 
-#' #' Additionally, to account for the influence of the number of species on each 
-#' clade (clade sample size), this function also estimate a null distribution of slopes
+#' Additionally, to account for the influence of the number of species on each 
+#' clade (clade sample size), this function also estimates a null distribution 
 #' expected for the number of species in a given clade. This is done by fitting
-#'  models without the same number of species in the given clade. 
-#'  The number of simulations to be performed is set by 'times'. To test if the 
-#'  clade influence differs from the null expectation, a randomization test can
-#'  be performed using 'summary(x)'. 
+#' models without the same number of species in the given clade. 
+#'  The number of simulations to be performed is set by 'n.sim'. To test if the 
+#'  clade influence differs from the null expectation for a clade of that size, 
+#'  a randomization test can be performed using 'summary(x)'. 
 #' 
-#' Currently, this function can only implement simple linear models (i.e. 
-#' \eqn{y = a + bx}). In the future we will implement more complex models.
+#' Currently, this function can only implement simple logistic models (i.e. \eqn{trait~
+#' predictor}). In the future we will implement more complex models.
 #'
 #' Output can be visualised using \code{sensi_plot}.
 #'
@@ -43,17 +56,20 @@
 #' @return \code{full.model.estimates}: Coefficients, aic and the optimised
 #' value of the phylogenetic parameter (e.g. \code{alpha}) for the full model
 #' without deleted species.
-#' @return \code{clade.model.estimates}: A data frame with all simulation
+#' @return \code{sensi.estimates}: A data frame with all simulation
 #' estimates. Each row represents a deleted clade. Columns report the calculated
 #' regression intercept (\code{intercept}), difference between simulation
-#' intercept and full model intercept (\code{DFintercept}), the percentage of change
+#' intercept and full model intercept (\code{DIFintercept}), the percentage of change
 #' in intercept compared to the full model (\code{intercept.perc}) and intercept
 #' p-value (\code{pval.intercept}). All these parameters are also reported for the regression
-#' slope (\code{DFslope} etc.). Additionally, model aic value (\code{AIC}) and
+#' slope (\code{DIFestimate} etc.). Additionally, model aic value (\code{AIC}) and
 #' the optimised value (\code{optpar}) of the phylogenetic parameter are
 #' reported.
+#' @return \code{null.dist}: A data frame with estimates for the null distributions
+#' for all clades analysed.
 #' @return \code{data}: Original full dataset.
 #' @return \code{errors}: Clades where deletion resulted in errors.
+#' @return \code{clade.col}: Which column was used to specify the clades?
 #' @author Gustavo Paterno & Gijsbert Werner
 #' @seealso \code{\link[phylolm]{phyloglm}}, \code{\link[sensiPhy]{clade_phylm}},
 #'  \code{\link{influ_phyglm}}, \code{\link{sensi_plot}}
@@ -70,7 +86,7 @@
 #'cla <- rep(c("A","B","C","D","E"), each = 30)
 #'dat = data.frame(y, x, cla)
 #'# Run sensitivity analysis:
-#'clade <- clade_phyglm(y ~ x, phy = phy, data = dat, times = 30, clade.col = "cla")
+#'clade <- clade_phyglm(y ~ x, phy = phy, data = dat, n.sim = 30, clade.col = "cla")
 #'# To check summary results and most influential clades:
 #'summary(clade)
 #'# Visual diagnostics for clade removal:
@@ -83,7 +99,7 @@
 #' @export
 
 clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
-                         clade.col, n.species = 5, times = 100,  ...){
+                         clade.col, n.species = 5, n.sim = 100,  ...){
   # To check summary results and most influential clades:
   
   
@@ -94,7 +110,7 @@ clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
   if(class(phy)!="phylo") stop("phy must be class 'phylo'")
   
   #Calculates the full model, extracts model parameters
-  data_phy <- match_dataphy(formula, data, phy)
+  data_phy <- match_dataphy(formula, data, phy, ...)
   phy <- data_phy$phy
   full.data <- data_phy$data
   if (is.na(match(clade.col, names(full.data)))) {
@@ -112,35 +128,35 @@ clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
                                   problem",sep=""))
   
   # FULL MODEL PARAMETERS:
-  N               <- nrow(full.data)
-  mod.0           <- phylolm::phyloglm(formula, data = full.data, 
+  N                <- nrow(full.data)
+  mod.0            <- phylolm::phyloglm(formula, data = full.data, 
                                        phy = phy, method = "logistic_MPLE",
                                        btol = btol)
   intercept.0      <- mod.0$coefficients[[1]]
-  slope.0          <- mod.0$coefficients[[2]]
+  estimate.0       <- mod.0$coefficients[[2]]
   pval.intercept.0 <- phylolm::summary.phylolm(mod.0)$coefficients[[1,4]]
-  pval.slope.0     <- phylolm::summary.phylolm(mod.0)$coefficients[[2,4]]
+  pval.estimate.0  <- phylolm::summary.phylolm(mod.0)$coefficients[[2,4]]
   optpar.0 <- mod.0$optpar
   
   if(isTRUE(mod.0$convergence!=0)) stop("Full model failed to converge,
                                         consider changing btol. See ?phyloglm")
   
   #Create dataframe to store estmates for each clade
-  clade.model.estimates <-
+  sensi.estimates <-
     data.frame("clade" =I(as.character()), 
                "N.species" = numeric(),"intercept"=numeric(),
-               "DFintercept"=numeric(),"intercept.perc"=numeric(),
-               "pval.intercept"=numeric(),"slope"=numeric(),
-               "DFslope"=numeric(),"slope.perc"=numeric(),
-               "pval.slope"=numeric(),"AIC"=numeric(),
+               "DIFintercept"=numeric(),"intercept.perc"=numeric(),
+               "pval.intercept"=numeric(),"estimate"=numeric(),
+               "DIFestimate"=numeric(),"estimate.perc"=numeric(),
+               "pval.estimate"=numeric(),"AIC"=numeric(),
                "optpar" = numeric())
   
   # Create dataframe store simulations (null distribution)
-  null.dist <- data.frame("clade" = rep(names(uc), each = times),
-                          "intercept"= numeric(length(uc)*times),
-                          "slope" = numeric(length(uc)*times),
-                          "DFintercept"=numeric(length(uc)*times),
-                          "DFslope"=numeric(length(uc)*times))
+  null.dist <- data.frame("clade" = rep(names(uc), each = n.sim),
+                          "intercept"= numeric(length(uc)*n.sim),
+                          "estimate" = numeric(length(uc)*n.sim),
+                          "DIFintercept"=numeric(length(uc)*n.sim),
+                          "DIFestimate"=numeric(length(uc)*n.sim))
   
   
   ### START LOOP between CLADES:
@@ -148,8 +164,8 @@ clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
   aa <- 1; bb <- 1
   errors <- NULL
   
-  pb <- utils::txtProgressBar(min = 0, max = length(uc)*times,
-                              style = 1)
+  if(track==TRUE) pb <- utils::txtProgressBar(min = 0, max = length(uc)*n.sim,
+                              style = 3)
   for (A in names(uc)){
     
     ### Number of species in clade A
@@ -162,53 +178,53 @@ clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
     mod=try(phylolm::phyloglm(formula, data = crop.data, 
                               phy = crop.phy, method = "logistic_MPLE",
                               btol = btol), TRUE)
-    intercept            <- mod$coefficients[[1]]
-    slope                <- mod$coefficients[[2]]
-    DFintercept          <- intercept - intercept.0
-    DFslope              <- slope - slope.0
-    intercept.perc       <- round((abs(DFintercept / intercept.0)) * 100,
+    intercept           <- mod$coefficients[[1]]
+    estimate            <- mod$coefficients[[2]]
+    DIFintercept        <- intercept - intercept.0
+    DIFestimate         <- estimate - estimate.0
+    intercept.perc      <- round((abs(DIFintercept / intercept.0)) * 100,
                                   digits = 1)
-    slope.perc           <- round((abs(DFslope / slope.0)) * 100,
+    estimate.perc       <- round((abs(DIFestimate / estimate.0)) * 100,
                                   digits = 1)
-    pval.intercept       <- phylolm::summary.phylolm(mod)$coefficients[[1,4]]
-    pval.slope           <- phylolm::summary.phylolm(mod)$coefficients[[2,4]]
-    aic.mod              <- mod$aic
-    optpar          <- mod$alpha
+    pval.intercept      <- phylolm::summary.phylolm(mod)$coefficients[[1,4]]
+    pval.estimate       <- phylolm::summary.phylolm(mod)$coefficients[[2,4]]
+    aic.mod             <- mod$aic
+    optpar              <- mod$alpha
     
     
     # Store reduced model parameters: 
-    estim.simu <- data.frame(A, cN, intercept, DFintercept, intercept.perc,
-                             pval.intercept, slope, DFslope, slope.perc,
-                             pval.slope, aic.mod, optpar,
+    estim.simu <- data.frame(A, cN, intercept, DIFintercept, intercept.perc,
+                             pval.intercept, estimate, DIFestimate, estimate.perc,
+                             pval.estimate, aic.mod, optpar,
                              stringsAsFactors = F)
-    clade.model.estimates[aa, ]  <- estim.simu
+    sensi.estimates[aa, ]  <- estim.simu
     
     ### START LOOP FOR NULL DIST:
     # number of species in clade A:
-    for (i in 1:times) {
+    for (i in 1:n.sim) {
       exclude <- sample(1:N, cN)
       crop.data <- full.data[-exclude,]
       crop.phy <-  ape::drop.tip(phy,phy$tip.label[exclude])
       mod=try(phylolm::phyloglm(formula, data = crop.data, 
                                 phy = crop.phy, method = "logistic_MPLE",
                                 btol = btol), TRUE)
-      intercept      <- mod$coefficients[[1]]
-      slope          <- mod$coefficients[[2]]
-      DFintercept          <- intercept - intercept.0
-      DFslope              <- slope - slope.0
+      intercept         <- mod$coefficients[[1]]
+      estimate          <- mod$coefficients[[2]]
+      DIFintercept      <- intercept - intercept.0
+      DIFestimate       <- estimate - estimate.0
       
-      null.dist[bb, ]  <- data.frame(clade = as.character(A), 
+      null.dist[bb, ]   <- data.frame(clade = as.character(A), 
                                      intercept,
-                                     slope,
-                                     DFintercept,
-                                     DFslope)
+                                     estimate,
+                                     DIFintercept,
+                                     DIFestimate)
       
       if(track==TRUE) utils::setTxtProgressBar(pb, bb)
       bb <- bb + 1
     }
     aa <- aa + 1
   }
-  on.exit(close(pb))
+  if(track==TRUE) on.exit(close(pb))
   
   #OUTPUT
   #full model estimates:
@@ -220,7 +236,7 @@ clade_phyglm <- function(formula, data, phy, btol=50, track = TRUE,
   res <- list(call = match.call(),
               formula = formula,
               full.model.estimates = param0,
-              clade.model.estimates = clade.model.estimates,
+              sensi.estimates = sensi.estimates,
               null.dist = null.dist, 
               data = full.data,
               errors = errors,
