@@ -81,7 +81,7 @@ influ_phylm <- function(formula,data,phy,model="lambda",cutoff=2,track=TRUE,...)
         if(class(formula)!="formula") stop("formula must be class 'formula'")
         if(class(data)!="data.frame") stop("data must be class 'data.frame'")
         if(class(phy)!="phylo") stop("phy must be class 'phylo'")
-        if ( (model == "trend") & (ape::is.ultrametric(phy)))
+        if ( (model == "trend") && (ape::is.ultrametric(phy)))
         stop("Trend is unidentifiable for ultrametric trees., see ?phylolm for details")
         else
 
