@@ -114,7 +114,7 @@ tree_samp_phylm <- function(formula, data, phy, n.sim = 30, n.tree = 2,
   if(class(phy)!="multiPhylo") stop("phy must be class 'multiPhylo'")
   if(length(phy)<n.tree) stop("'times' must be smaller (or equal) than the number of trees in the 'multiPhylo' object")
   if(length(breaks) < 2)  stop("Please include more than one break, e.g. breaks=c(.3,.5)")
-  if((model == "trend") & (sum(is.ultrametric(phy))>1)) 
+  if((model == "trend") && (sum(is.ultrametric(phy))>1)) 
     stop("Trend is unidentifiable for ultrametric trees., see ?phylolm for details")
   else
   
